#Zainstaluje potrzebne pakiety
install.packages(c("tidyverse", "ggplot2"))

#Załaduj potrzebne pakiety
library(tidyverse)
library(ggplot2)

#Przekszłtać dane na szereg czasowy i zerknij jak kształowała się umieralność w Polsce
dane <- ts(zgony$Poland)
plot(dane)

#Rozdziel kolumnę TIME na dane dotyczące roku i tygodnia
zgony <- zgony %>%
  separate(TIME, into = c("Rok", "Tydzień"), sep = "-W")

#Sprawdź strukturę danych
str(zgony)

#Zamień typ danych
zgony$Rok <- as.numeric(zgony$Rok)
zgony$Tydzień <- as.numeric(zgony$Tydzień)

#Sprawdź strukturę danych jeszcze raz ;)
str(zgony)

#Wybierz dane za okres 2000-2019 będące podstawą wyliczenia oczekiwanej umieralności
wybrane <- zgony %>%
  filter(Rok >= 2000 & Rok <= 2019)

#Oblicz średnią umieralność w każdym tygodniu
Baseline <- wybrane %>%
  group_by(Tydzień) %>%
  summarise(Oczekiwane_PL = mean(Poland, na.rm = TRUE))

#Wygeneruj wykres pokazujący kształtowanie się oczekiwanej umieralności w Polsce
ggplot(Baseline, aes(x = Tydzień, y = Oczekiwane_PL)) +
  geom_line() +
  geom_smooth(method = "loess", se = FALSE, color = "red") +  # Add a smoothing line
  labs(title = "Oczekiwana umieralność w Polsce w ujęciu tygodniowym",
       x = "Tydzień",
       y = "Surowy współczynnik zgonów") +
  theme_minimal()

#Wizualizacja, dla osi Y znaczynającej się od 0
ggplot(Baseline, aes(x = Tydzień, y = Oczekiwane_PL)) +
  geom_line() +
  geom_smooth(method = "loess", se = FALSE, color = "red") +  # Add a smoothing line
    labs(title = "Oczekiwana umieralność w Polsce w ujęciu tygodniowym",
       x = "Tydzień",
       y = "Surowy współczynnik zgonów") +
  scale_y_continuous(limits = c(0, max(Baseline$Oczekiwane_PL)), expand = c(0, 0)) +
  theme_minimal()

#Dołącz Oczekiwaną umieralność do wejściowego zbioru danych
zgony <- zgony %>%
  left_join(Baseline, by = "Tydzień")

#Oblicz różnicę pomiędzy rzeczywistą i oczekiwaną umieralnością
zgony <- zgony %>%
  mutate(Nadumieralność = Poland - Oczekiwane_PL)

#Pokaż dane od roku 2020
zgony <- as.data.frame(zgony)
pandemia <- zgony %>%
  filter(Rok >= 2020)

#Wizualizacja nadumieralność w okresie pandemii
pandemia_ts <- ts(pandemia[, c("Oczekiwane_PL", "Nadumieralność")])
pandemia_df <- data.frame(Tydzień = time(pandemia_ts), as.data.frame(pandemia_ts))
ggplot(pandemia_df, aes(x = Tydzień, y = Oczekiwane_PL, group = 1)) +
  geom_line(aes(color = "Oczekiwane_PL"), linetype = "dashed") +
  geom_line(aes(x = Tydzień, y = Nadumieralność, color = "Nadumieralność"), linetype = "solid") +
  labs(title = "Tygodniowa nadumieralność w Polsce",
       y = "Surowy współczynnik zgonów",
       color = "Legenda") +
  theme_minimal()
